summaryrefslogtreecommitdiffstats
path: root/examples/rainfall/variantdataset.h
diff options
context:
space:
mode:
Diffstat (limited to 'examples/rainfall/variantdataset.h')
-rw-r--r--examples/rainfall/variantdataset.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/rainfall/variantdataset.h b/examples/rainfall/variantdataset.h
index f3965978..7906d4f5 100644
--- a/examples/rainfall/variantdataset.h
+++ b/examples/rainfall/variantdataset.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
** This file is part of the QtDataVis3D module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
@@ -19,11 +19,11 @@
#ifndef VARIANTDATASET_H
#define VARIANTDATASET_H
-#include "qdatavis3denums.h"
+#include "qdatavisualizationenums.h"
#include <QScopedPointer>
#include <QVariantList>
-using namespace QtDataVis3D;
+using namespace QtDataVisualization;
typedef QVariantList VariantDataItem;
typedef QList<VariantDataItem *> VariantDataItemList;
@@ -4,7 +4,7 @@
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in